#!/usr/bin/env python3
# import argparse
import os
import shutil
import random
import subprocess

from mpd import MPDClient

# if "XDG_DATA_HOME" in os.environ:
#     _BLISSIFY_DATA_HOME = os.path.expandvars("$XDG_DATA_HOME/blissify")
# else:
#     _BLISSIFY_DATA_HOME = os.path.expanduser("~/.local/share/blissify")

def init_connection():
    """
    Returns an MPDClient connection.
    """
    # Get MPD connection settings
    try:
        mpd_host = os.environ["MPD_HOST"]
        if "@" in mpd_host:
            mpd_password, mpd_host = mpd_host.split("@")
    except KeyError:
        mpd_host = "localhost"
        mpd_password = None
    try:
        mpd_port = os.environ["MPD_PORT"]
    except KeyError:
        mpd_port = 6600

    # Connect to MPD
    client = MPDClient()
    client.connect(mpd_host, mpd_port)
    if mpd_password is not None:
        client.password(mpd_password)
    return client

def close_connection(client):
    """
    Closes an MPDClient connection.
    """
    client.close()
    client.disconnect()

def listen():
    """
    Listen for additions in MPD library using MPD IDLE and handle them
    immediately.
    """
    conf_path = os.path.join("/etc/blissify.conf")
    metric=['euclidean', 'cosine']
    client = init_connection()
    while True:
        try:
            if client.idle() == ['player']:
                playnum = int (client.status()['song']) + 1
                listlength = int (client.status()['playlistlength'])
                if playnum == listlength:
                    subprocess.check_call(['blissify', '-c', conf_path, 'playlist', '--distance', metric[random.randint(0, 1)], str(random.randint(8, 16)) ])
            if client.idle() == ['update']:
                subprocess.check_call(['blissify', '-c', conf_path, 'update'])
        except KeyboardInterrupt:
            break
    close_connection(client)

# if __name__ == "__main__":
#     parser = argparse.ArgumentParser()
#     parser.add_argument("mpd_root", help="Root folder of your MPD library.")

#     group = parser.add_mutually_exclusive_group(required=True)
#     group.add_argument("--full-rescan", help="Scan the whole library.",
#                        action="store_true", default=False)
#     group.add_argument("--rescan-errored", help="Rescan errored files.",
#                        action="store_true", default=False)
#     group.add_argument("--update",
#                        help="Update the database with new files in the library",
#                        action="store_true", default=False)
#     group.add_argument("--listen",
#                        help="Listen for MPD IDLE signals to do live scanning.",
#                        action="store_true", default=False)

#     args = parser.parse_args()

#     if args.full_rescan:
#         listen(args.mpd_root)
#     else:
#         sys.exit()

listen()
